# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tensorboard/uploader/proto/blob.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='tensorboard/uploader/proto/blob.proto',
  package='tensorboard.service',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n%tensorboard/uploader/proto/blob.proto\x12\x13tensorboard.service\"F\n\x04\x42lob\x12\x0f\n\x07\x62lob_id\x18\x01 \x01(\t\x12-\n\x05state\x18\x02 \x01(\x0e\x32\x1e.tensorboard.service.BlobState\"<\n\x11\x42lobSequenceEntry\x12\'\n\x04\x62lob\x18\x01 \x01(\x0b\x32\x19.tensorboard.service.Blob\"G\n\x0c\x42lobSequence\x12\x37\n\x07\x65ntries\x18\x01 \x03(\x0b\x32&.tensorboard.service.BlobSequenceEntry*W\n\tBlobState\x12\x16\n\x12\x42LOB_STATE_UNKNOWN\x10\x00\x12\x1a\n\x16\x42LOB_STATE_UNFINALIZED\x10\x01\x12\x16\n\x12\x42LOB_STATE_CURRENT\x10\x02\x62\x06proto3')
)

_BLOBSTATE = _descriptor.EnumDescriptor(
  name='BlobState',
  full_name='tensorboard.service.BlobState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BLOB_STATE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BLOB_STATE_UNFINALIZED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BLOB_STATE_CURRENT', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=269,
  serialized_end=356,
)
_sym_db.RegisterEnumDescriptor(_BLOBSTATE)

BlobState = enum_type_wrapper.EnumTypeWrapper(_BLOBSTATE)
BLOB_STATE_UNKNOWN = 0
BLOB_STATE_UNFINALIZED = 1
BLOB_STATE_CURRENT = 2



_BLOB = _descriptor.Descriptor(
  name='Blob',
  full_name='tensorboard.service.Blob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blob_id', full_name='tensorboard.service.Blob.blob_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='tensorboard.service.Blob.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=132,
)


_BLOBSEQUENCEENTRY = _descriptor.Descriptor(
  name='BlobSequenceEntry',
  full_name='tensorboard.service.BlobSequenceEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blob', full_name='tensorboard.service.BlobSequenceEntry.blob', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=194,
)


_BLOBSEQUENCE = _descriptor.Descriptor(
  name='BlobSequence',
  full_name='tensorboard.service.BlobSequence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='tensorboard.service.BlobSequence.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=196,
  serialized_end=267,
)

_BLOB.fields_by_name['state'].enum_type = _BLOBSTATE
_BLOBSEQUENCEENTRY.fields_by_name['blob'].message_type = _BLOB
_BLOBSEQUENCE.fields_by_name['entries'].message_type = _BLOBSEQUENCEENTRY
DESCRIPTOR.message_types_by_name['Blob'] = _BLOB
DESCRIPTOR.message_types_by_name['BlobSequenceEntry'] = _BLOBSEQUENCEENTRY
DESCRIPTOR.message_types_by_name['BlobSequence'] = _BLOBSEQUENCE
DESCRIPTOR.enum_types_by_name['BlobState'] = _BLOBSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Blob = _reflection.GeneratedProtocolMessageType('Blob', (_message.Message,), {
  'DESCRIPTOR' : _BLOB,
  '__module__' : 'tensorboard.uploader.proto.blob_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.Blob)
  })
_sym_db.RegisterMessage(Blob)

BlobSequenceEntry = _reflection.GeneratedProtocolMessageType('BlobSequenceEntry', (_message.Message,), {
  'DESCRIPTOR' : _BLOBSEQUENCEENTRY,
  '__module__' : 'tensorboard.uploader.proto.blob_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.BlobSequenceEntry)
  })
_sym_db.RegisterMessage(BlobSequenceEntry)

BlobSequence = _reflection.GeneratedProtocolMessageType('BlobSequence', (_message.Message,), {
  'DESCRIPTOR' : _BLOBSEQUENCE,
  '__module__' : 'tensorboard.uploader.proto.blob_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.BlobSequence)
  })
_sym_db.RegisterMessage(BlobSequence)


# @@protoc_insertion_point(module_scope)
